==> eiffelstudio-18.11.10.2592.tar: F_code/C5/xm222.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm222.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F287_2841 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1847, 0).id);
	F1848_18245(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {1418,1161,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1415_13770(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.document */
EIF_REFERENCE F287_2842 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.last_position_table */
EIF_REFERENCE F287_2844 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F287_2845 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(41, 0).id);
	F42_557(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F287_2847 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F287_2841(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F287_2848 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLR(9,tr3);
	RTLIU(10);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		tr1 = RTLNS(eif_new_type(1848, 0x00).id, 1848, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr2 = F287_2855(Current, loc2, arg2);
		F1849_18261(RTCW(tr1), loc3, arg3, tr2);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1848, 0x00).id, 1848, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr3 = F287_2855(Current, loc2, arg2);
		F1849_18262(RTCW(tr1), tr2, arg3, tr3);
		loc1 = (EIF_REFERENCE) tr1;
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F287_2857(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F287_2849 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(10);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLR(9,arg4);
	RTLIU(10);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = RTLNS(eif_new_type(1845, 0x00).id, 1845, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr2 = F287_2855(Current, loc2, arg2);
	F1846_18198(RTCW(tr1), arg3, tr2, arg4, loc3);
	loc1 = (EIF_REFERENCE) tr1;
	F287_2857(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F287_2850 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = RTLNS(eif_new_type(1843, 0x00).id, 1843, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1844_18181(RTCW(tr1), loc2, arg1);
	loc1 = (EIF_REFERENCE) tr1;
	F287_2857(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F287_2851 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !EIF_TEST(loc2))) {
		tb2 = F1838_18156(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1838_18153(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F287_2852 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(7);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTLNS(eif_new_type(1842, 0x00).id, 1842, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1843_18173(RTCW(tr1), loc2, arg1, arg2);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1842, 0x00).id, 1842, _OBJSIZ_3_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1843_18174(RTCW(tr1), tr2, arg1, arg2);
		loc1 = (EIF_REFERENCE) tr1;
	}
	F287_2857(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F287_2853 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,tr2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTLNS(eif_new_type(1841, 0x00).id, 1841, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1842_18167(RTCW(tr1), loc2, arg1);
		loc1 = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1841, 0x00).id, 1841, _OBJSIZ_2_0_0_0_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1842_18168(RTCW(tr1), tr2, arg1);
		loc1 = (EIF_REFERENCE) tr1;
	}
	F287_2857(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.current_element */
EIF_REFERENCE F287_2854 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F287_2855 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg2);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1161, 0x00).id, 1161, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1162_11117(RTCW(tr1), arg2, arg1);
	Result = (EIF_REFERENCE) tr1;
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1415_13775(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1415_13773(RTCW(tr1), Result);
		tb2 = F1162_11124(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		Result = F1415_13773(RTCW(tr1), Result);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1415_13786(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.namespace_cache */
EIF_REFERENCE F287_2856 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F287_2857 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F1911_20793(loc2);
		F42_560(loc1, tr1, arg1);
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.source_parser */
EIF_REFERENCE F287_2858 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


void EIF_Minit222 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/xm222.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm222.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F289_2771 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1791, 1).id);
	F1792_17405(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1354,0xFF01,1091,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1351_12474(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F289_2775 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(32, 0).id);
	F33_344(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F289_2777 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F289_2771(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F289_2778 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc1 = RTLNS(eif_new_type(1792, 0x01).id, 1792, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = F289_2785(Current, loc2, arg2);
		F1793_17421(RTCW(loc1), loc3, arg3, tr1);
	} else {
		loc1 = RTLNS(eif_new_type(1792, 0x01).id, 1792, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F289_2785(Current, loc2, arg2);
		F1793_17422(RTCW(loc1), tr1, arg3, tr2);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F289_2787(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F289_2779 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,arg4);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1789, 0x01).id, 1789, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr1 = F289_2785(Current, loc2, arg2);
	F1790_17358(RTCW(loc1), arg3, tr1, arg4, loc3);
	F289_2787(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F289_2780 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1787, 0x01).id, 1787, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1788_17341(RTCW(loc1), loc2, arg1);
	F289_2787(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F289_2781 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !(EIF_TRUE))) {
		tb2 = F1782_17316(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1782_17313(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F289_2782 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1786, 0x01).id, 1786, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1787_17333(RTCW(loc1), loc2, arg1, arg2);
	} else {
		loc1 = RTLNS(eif_new_type(1786, 0x01).id, 1786, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1787_17334(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1, arg2);
	}
	F289_2787(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F289_2783 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1785, 0x01).id, 1785, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1786_17327(RTCW(loc1), loc2, arg1);
	} else {
		loc1 = RTLNS(eif_new_type(1785, 0x01).id, 1785, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1786_17328(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1);
	}
	F289_2787(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F289_2785 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTGC;
	Result = RTLNS(eif_new_type(1091, 0x01).id, 1091, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1092_10367(RTCW(Result), arg2, arg1);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1351_12479(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1351_12477(RTCW(tr1), Result);
		tb2 = F1092_10374(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1351_12477(RTCW(tr1), Result);
		Result = (EIF_REFERENCE) tr1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1351_12490(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F289_2787 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F1844_21259(loc2);
		F33_347(loc1, tr1, arg1);
	}
	RTLE;
}

void EIF_Minit222 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
